@@ -2,12 +2,13 @@
 
 __author__ = """Andres Kepler"""
 __email__ = 'andres.kepler@fleetcomplete.com'
-__version__ = '0.1.14'
+__version__ = '0.1.15'
 
 import datetime
 import struct
 import logging
 import re
+import json
 import logstash
 from scapy.all import *
 from logstash_formatter import LogstashFormatterV1
@@ -71,18 +72,28 @@ class DataOut(object):
     def __repr__(self):
         return str(self.__dict__())
 
-
-def get_vt10_serial(packet):
+def get_json_serial(packet):
+    serial = None
     try:
-        serial = struct.unpack_from(">16s", bytes(packet), offset=54)[0].decode('utf8')
+        raw_json_data = struct.unpack_from(">256s", bytes(packet), offset=54)[0].decode('utf8')
+        json_data = json.loads(raw_json_data)
+        serial = json_data[0].get("terminalSerial")
     except Exception as e:
         logging.debug(e)
         return None
-    if "," in serial:
-        serial = serial.split(",")[0]
-    else:
+    return serial
+
+def get_vt10_serial(packet):
+    serial = None
+    try:
+        pkt_data = struct.unpack_from(">64s", bytes(packet), offset=54)[0].decode('utf8')
+        pkt_match = re.match("(\d{15}),(\d{10}),(\d{14}),.*", pkt_data)
+    except Exception as e:
+        logging.debug(e)
         return None
-    return str(serial)
+    if pkt_match:
+        serial = str(pkt_match.group(1))
+    return serial
 
 
 def get_ruptela_serial(packet):
@@ -135,6 +146,7 @@ def parse_file(args):
         t_serial = get_teltonika_serial(packet)
         r_serial = get_ruptela_serial(packet)
         v_serial = get_vt10_serial(packet)
+        j_serial = get_json_serial(packet)
 
         if t_serial:
             terminal_type = "Teltonika"
@@ -145,6 +157,9 @@ def parse_file(args):
         elif v_serial:
             terminal_type = "VT10"
             serial = v_serial
+        elif j_serial:
+            terminal_type = "JSON"
+            serial = j_serial
         else:
             continue
 
@@ -157,6 +172,7 @@ def parse_file(args):
                           )
         if serial not in serial_collector:
             serial_collector.append(serial)
-            logging.info({"terminal_serial": payload.terminal_serial}, extra=payload.__dict__())
+            logging.info({"terminal_serial": payload.terminal_serial, "terminal_type": payload.terminal_type},
+                         extra=payload.__dict__())
     logging.debug("Stop")
     return 0
